/* client_pty.h
 *
 * $Id: client_pty.h,v 1.5 2000/11/15 21:54:50 nisse Exp $ */

/* lsh, an implementation of the ssh protocol
 *
 * Copyright (C) 1998, 1999, Niels Mller, Balzs Scheidler
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifndef LSH_CLIENT_PTY_H_INCLUDED
#define LSH_CLIENT_PTY_H_INCLUDED

#include "lsh.h"
#include "command.h"

struct interact;

struct command *make_pty_request(struct interact *tty);

#endif /* LSH_CLIENT_PTY_H_INCLUDED */

